pub struct ArchiveIssueResult {
pub success: bool,
}Fields
success: boolTrait Implementations
Sourceimpl Clone for ArchiveIssueResult
impl Clone for ArchiveIssueResult
Sourcefn clone(&self) -> ArchiveIssueResult
fn clone(&self) -> ArchiveIssueResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArchiveIssueResult
impl Debug for ArchiveIssueResult
Sourceimpl<'de> Deserialize<'de> for ArchiveIssueResult
impl<'de> Deserialize<'de> for ArchiveIssueResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArchiveIssueResult
impl JsonSchema for ArchiveIssueResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ArchiveIssueResult
impl Serialize for ArchiveIssueResult
Sourceimpl TextFormat for ArchiveIssueResult
impl TextFormat for ArchiveIssueResult