pub struct CommentResult {
pub success: bool,
pub comment_id: Option<String>,
pub body: Option<String>,
pub created_at: Option<String>,
}Fields
success: boolcomment_id: Option<String>body: Option<String>created_at: Option<String>Trait Implementations
Sourceimpl Clone for CommentResult
impl Clone for CommentResult
Sourcefn clone(&self) -> CommentResult
fn clone(&self) -> CommentResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommentResult
impl Debug for CommentResult
Sourceimpl<'de> Deserialize<'de> for CommentResult
impl<'de> Deserialize<'de> for CommentResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommentResult
impl JsonSchema for CommentResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CommentResult
impl Serialize for CommentResult
Sourceimpl TextFormat for CommentResult
impl TextFormat for CommentResult