pub struct CommentSummary {
pub id: String,
pub body: String,
pub url: String,
pub created_at: String,
pub updated_at: String,
pub parent_id: Option<String>,
pub author_name: Option<String>,
pub author_email: Option<String>,
}Fields
id: Stringbody: Stringurl: Stringcreated_at: Stringupdated_at: Stringparent_id: Option<String>Trait Implementations
Sourceimpl Clone for CommentSummary
impl Clone for CommentSummary
Sourcefn clone(&self) -> CommentSummary
fn clone(&self) -> CommentSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommentSummary
impl Debug for CommentSummary
Sourceimpl<'de> Deserialize<'de> for CommentSummary
impl<'de> Deserialize<'de> for CommentSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommentSummary
impl JsonSchema for CommentSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommentSummary
impl RefUnwindSafe for CommentSummary
impl Send for CommentSummary
impl Sync for CommentSummary
impl Unpin for CommentSummary
impl UnsafeUnpin for CommentSummary
impl UnwindSafe for CommentSummary