pub struct CommentsResult {
pub issue_identifier: String,
pub comments: Vec<CommentSummary>,
pub shown_comments: usize,
pub total_comments: usize,
pub has_more: bool,
}Fields
issue_identifier: Stringcomments: Vec<CommentSummary>shown_comments: usizetotal_comments: usizehas_more: boolTrait Implementations
Sourceimpl Clone for CommentsResult
impl Clone for CommentsResult
Sourcefn clone(&self) -> CommentsResult
fn clone(&self) -> CommentsResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommentsResult
impl Debug for CommentsResult
Sourceimpl<'de> Deserialize<'de> for CommentsResult
impl<'de> Deserialize<'de> for CommentsResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommentsResult
impl JsonSchema for CommentsResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CommentsResult
impl Serialize for CommentsResult
Sourceimpl TextFormat for CommentsResult
impl TextFormat for CommentsResult