pub struct GetMetadataResult {
pub kind: MetadataKind,
pub items: Vec<MetadataItem>,
pub has_next_page: bool,
pub end_cursor: Option<String>,
}Fields
kind: MetadataKinditems: Vec<MetadataItem>has_next_page: boolend_cursor: Option<String>Trait Implementations
Sourceimpl Clone for GetMetadataResult
impl Clone for GetMetadataResult
Sourcefn clone(&self) -> GetMetadataResult
fn clone(&self) -> GetMetadataResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetMetadataResult
impl Debug for GetMetadataResult
Sourceimpl<'de> Deserialize<'de> for GetMetadataResult
impl<'de> Deserialize<'de> for GetMetadataResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetMetadataResult
impl JsonSchema for GetMetadataResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for GetMetadataResult
impl Serialize for GetMetadataResult
Sourceimpl TextFormat for GetMetadataResult
impl TextFormat for GetMetadataResult