pub struct IssueDetails {
pub issue: IssueSummary,
pub description: Option<String>,
pub estimate: Option<f64>,
pub parent: Option<ParentIssueRef>,
pub started_at: Option<String>,
pub completed_at: Option<String>,
pub canceled_at: Option<String>,
}Fields
issue: IssueSummarydescription: Option<String>estimate: Option<f64>parent: Option<ParentIssueRef>started_at: Option<String>completed_at: Option<String>canceled_at: Option<String>Trait Implementations
Sourceimpl Clone for IssueDetails
impl Clone for IssueDetails
Sourcefn clone(&self) -> IssueDetails
fn clone(&self) -> IssueDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IssueDetails
impl Debug for IssueDetails
Sourceimpl<'de> Deserialize<'de> for IssueDetails
impl<'de> Deserialize<'de> for IssueDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IssueDetails
impl JsonSchema for IssueDetails
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for IssueDetails
impl Serialize for IssueDetails
Sourceimpl TextFormat for IssueDetails
impl TextFormat for IssueDetails