pub struct IssueResult {
pub issue: IssueSummary,
}Fields
issue: IssueSummaryTrait Implementations
Sourceimpl Clone for IssueResult
impl Clone for IssueResult
Sourcefn clone(&self) -> IssueResult
fn clone(&self) -> IssueResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IssueResult
impl Debug for IssueResult
Sourceimpl<'de> Deserialize<'de> for IssueResult
impl<'de> Deserialize<'de> for IssueResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IssueResult
impl JsonSchema for IssueResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for IssueResult
impl Serialize for IssueResult
Sourceimpl TextFormat for IssueResult
impl TextFormat for IssueResult