pub struct IssueSummary {Show 15 fields
pub id: String,
pub identifier: String,
pub title: String,
pub url: String,
pub team: TeamRef,
pub state: Option<WorkflowStateRef>,
pub assignee: Option<UserRef>,
pub creator: Option<UserRef>,
pub project: Option<ProjectRef>,
pub priority: i32,
pub priority_label: String,
pub label_ids: Vec<String>,
pub due_date: Option<String>,
pub created_at: String,
pub updated_at: String,
}Fields
id: Stringidentifier: Stringtitle: Stringurl: Stringteam: TeamRefstate: Option<WorkflowStateRef>assignee: Option<UserRef>creator: Option<UserRef>project: Option<ProjectRef>priority: i32priority_label: Stringlabel_ids: Vec<String>due_date: Option<String>created_at: Stringupdated_at: StringTrait Implementations
Sourceimpl Clone for IssueSummary
impl Clone for IssueSummary
Sourcefn clone(&self) -> IssueSummary
fn clone(&self) -> IssueSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IssueSummary
impl Debug for IssueSummary
Sourceimpl<'de> Deserialize<'de> for IssueSummary
impl<'de> Deserialize<'de> for IssueSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Issue> for IssueSummary
impl From<Issue> for IssueSummary
Sourceimpl From<IssueSearchResult> for IssueSummary
impl From<IssueSearchResult> for IssueSummary
Sourcefn from(i: IssueSearchResult) -> Self
fn from(i: IssueSearchResult) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for IssueSummary
impl JsonSchema for IssueSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for IssueSummary
impl RefUnwindSafe for IssueSummary
impl Send for IssueSummary
impl Sync for IssueSummary
impl Unpin for IssueSummary
impl UnsafeUnpin for IssueSummary
impl UnwindSafe for IssueSummary