pub struct MetadataItem {
pub id: String,
pub name: String,
pub key: Option<String>,
pub email: Option<String>,
pub state_type: Option<String>,
pub team_id: Option<String>,
}Fields
id: Stringname: Stringkey: Option<String>email: Option<String>state_type: Option<String>team_id: Option<String>Trait Implementations
Sourceimpl Clone for MetadataItem
impl Clone for MetadataItem
Sourcefn clone(&self) -> MetadataItem
fn clone(&self) -> MetadataItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetadataItem
impl Debug for MetadataItem
Sourceimpl<'de> Deserialize<'de> for MetadataItem
impl<'de> Deserialize<'de> for MetadataItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MetadataItem
impl JsonSchema for MetadataItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MetadataItem
impl RefUnwindSafe for MetadataItem
impl Send for MetadataItem
impl Sync for MetadataItem
impl Unpin for MetadataItem
impl UnwindSafe for MetadataItem