pub struct ParentIssueRef {
pub id: String,
pub identifier: String,
}Fields
id: Stringidentifier: StringTrait Implementations
Sourceimpl Clone for ParentIssueRef
impl Clone for ParentIssueRef
Sourcefn clone(&self) -> ParentIssueRef
fn clone(&self) -> ParentIssueRef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParentIssueRef
impl Debug for ParentIssueRef
Sourceimpl<'de> Deserialize<'de> for ParentIssueRef
impl<'de> Deserialize<'de> for ParentIssueRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ParentIssue> for ParentIssueRef
impl From<ParentIssue> for ParentIssueRef
Sourcefn from(p: ParentIssue) -> Self
fn from(p: ParentIssue) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ParentIssueRef
impl JsonSchema for ParentIssueRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ParentIssueRef
impl RefUnwindSafe for ParentIssueRef
impl Send for ParentIssueRef
impl Sync for ParentIssueRef
impl Unpin for ParentIssueRef
impl UnsafeUnpin for ParentIssueRef
impl UnwindSafe for ParentIssueRef