pub struct ProjectRef {
pub id: String,
pub name: String,
}Fields
id: Stringname: StringTrait Implementations
Sourceimpl Clone for ProjectRef
impl Clone for ProjectRef
Sourcefn clone(&self) -> ProjectRef
fn clone(&self) -> ProjectRef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectRef
impl Debug for ProjectRef
Sourceimpl<'de> Deserialize<'de> for ProjectRef
impl<'de> Deserialize<'de> for ProjectRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Project> for ProjectRef
impl From<Project> for ProjectRef
Sourceimpl JsonSchema for ProjectRef
impl JsonSchema for ProjectRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProjectRef
impl RefUnwindSafe for ProjectRef
impl Send for ProjectRef
impl Sync for ProjectRef
impl Unpin for ProjectRef
impl UnsafeUnpin for ProjectRef
impl UnwindSafe for ProjectRef