pub struct TeamRef {
pub id: String,
pub key: String,
pub name: String,
}Fields
id: Stringkey: Stringname: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for TeamRef
impl<'de> Deserialize<'de> for TeamRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TeamRef
impl JsonSchema for TeamRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TeamRef
impl RefUnwindSafe for TeamRef
impl Send for TeamRef
impl Sync for TeamRef
impl Unpin for TeamRef
impl UnsafeUnpin for TeamRef
impl UnwindSafe for TeamRef