pub struct UserRef {
pub id: String,
pub name: String,
pub email: String,
}Fields
id: Stringname: Stringemail: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for UserRef
impl<'de> Deserialize<'de> for UserRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserRef
impl JsonSchema for UserRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UserRef
impl RefUnwindSafe for UserRef
impl Send for UserRef
impl Sync for UserRef
impl Unpin for UserRef
impl UnsafeUnpin for UserRef
impl UnwindSafe for UserRef