pub struct WorkflowStateRef {
pub id: String,
pub name: String,
pub state_type: String,
}Fields
id: Stringname: Stringstate_type: StringTrait Implementations
Sourceimpl Clone for WorkflowStateRef
impl Clone for WorkflowStateRef
Sourcefn clone(&self) -> WorkflowStateRef
fn clone(&self) -> WorkflowStateRef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkflowStateRef
impl Debug for WorkflowStateRef
Sourceimpl<'de> Deserialize<'de> for WorkflowStateRef
impl<'de> Deserialize<'de> for WorkflowStateRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<WorkflowState> for WorkflowStateRef
impl From<WorkflowState> for WorkflowStateRef
Sourcefn from(s: WorkflowState) -> Self
fn from(s: WorkflowState) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for WorkflowStateRef
impl JsonSchema for WorkflowStateRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkflowStateRef
impl RefUnwindSafe for WorkflowStateRef
impl Send for WorkflowStateRef
impl Sync for WorkflowStateRef
impl Unpin for WorkflowStateRef
impl UnsafeUnpin for WorkflowStateRef
impl UnwindSafe for WorkflowStateRef